
XEP-0462: PubSub Type Filtering
===============================

.. module:: slixmpp.plugins.xep_0462

.. autoclass:: XEP_0462
    :members:
    :exclude-members: session_bind, plugin_init, plugin_end


Stanza elements
---------------

.. automodule:: slixmpp.plugins.xep_0462.stanza
    :members:
    :undoc-members:
